MutableOrderedList<V> class
A mutable ordered collection that maintains insertion order and provides list-like operations.
This class extends Iterable and provides methods for adding, removing, and clearing items while preserving the order in which they were added. It's designed for scenarios where maintaining insertion order is important and the collection needs to be modified frequently.
final list = MutableOrderedList<String>();
list.add('first');
list.add('second');
list.add('third');
print(list); // ['first', 'second', 'third']
@ai Use this class when you need a mutable collection with guaranteed insertion order. Consider using ImmutableOrderedList if you need immutability guarantees.
- Mixed-in types
-
- Iterable<
V>
- Iterable<
- Available extensions
Constructors
Properties
- first → V
-
The first element.
no setterinherited
- firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter - isEmpty → bool
-
Whether this collection has no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
-
iterator
→ Iterator<
V> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setteroverride - last → V
-
The last element.
no setterinherited
- lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - length → int
-
The number of elements in this Iterable.
no setterinherited
-
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → V
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
- singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter -
toJSIterable
→ JSIterable<
T> -
Available on Iterable<
A JSIterable wrapper that proxies to the Dart iterable API.T> , provided by the IterableToJSIterable extensionno setter -
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
add(
V value) → void -
Adds the specified
valueto the end of this ordered list. -
any(
bool test(V element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
cast<
R> () → Iterable< R> -
A view of this iterable as an iterable of
Rinstances.inherited -
clear(
) → void - Removes all items from this ordered list.
-
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.inherited -
elementAt(
int index) → V -
Returns the
indexth element.inherited -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
every(
bool test(V element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> toElements(V element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
firstWhere(
bool test(V element), {V orElse()?}) → V -
The first element that satisfies the given predicate
test.inherited -
fold<
T> (T initialValue, T combine(T previousValue, V element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
followedBy(
Iterable< V> other) → Iterable<V> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(V value)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastWhere(
bool test(V element), {V orElse()?}) → V -
The last element that satisfies the given predicate
test.inherited -
map<
T> (T toElement(V e)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reduce(
V combine(V value, V element)) → V -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
remove(
V value) → void -
Removes the first occurrence of the specified
valuefrom this ordered list. -
singleWhere(
bool test(V element), {V orElse()?}) → V -
The single element that satisfies
test.inherited -
skip(
int count) → Iterable< V> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(V element)) → Iterable< V> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
take(
int count) → Iterable< V> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeWhile(
bool test(V element)) → Iterable< V> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
toList(
{bool growable = true}) → List< V> -
Creates a List containing the elements of this Iterable.
inherited
-
toSet(
) → Set< V> -
Creates a Set containing the same elements as this iterable.
inherited
-
toString(
) → String -
Returns a string representation of (some of) the elements of
this.inherited -
where(
bool test(V element)) → Iterable< V> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereType<
T> () → Iterable< R> -
Creates a new lazy Iterable with all elements that have type
T.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → V -
Retrieves the item at the specified
index. -
operator []=(
int index, V value) → void -
Sets the item at the specified
indexto the specifiedvalue.